query renderCSS($ssml: String!, $css: String) {
  callCompose(
    init: { styled_ssml: $ssml, voice_css: $css }
    pipeline: [
      { op: "callApplyVoiceCSS", transform: "r => ({text: r.ssml})" }
      { op: "callTextToSpeech", transform: "" }
    ]
  ) {
    result
  }
}